export default {
  "New layer": "New layer",
  "Elements on layer {0}": "Elements on layer {0}",
  "Layers": "Layers",
  "Project config": "Project config",
  "width": "width",
  "height": "height",
  "Cancel": "Cancel",
  "Save": "Save",
  "Layer config": "Layer config",
  "name": "name",
  "opacity": "opacity",
  "altitude": "altitude",
  "order": "order",
  "Delete": "Delete",
  "New project": "New project",
  "Save project": "Save project",
  "Load project": "Load project",
  "3D View": "3D View",
  "2D View": "2D View",
  "3D First Person": "3D First Person",
  "Zoom in": "Zoom in",
  "Zoom out": "Zoom out",
  "Pan": "Pan",
  "Undo (CTRL-Z)": "Undo (CTRL-Z)",
  "Configure project": "Configure project",
  "Open catalog": "Open catalog",
  "Reset": "Reset",
  "Unselect": "Unselect",
  "Configure layer": "Configure layer",
  "Properties: [{0}] {1}": "Properties: [{0}] {1}",
  "Get Screenshot": "Get Screenshot",
  "Catalog": "Catalog",
  "Rotation": "Rotation",
  "Altitude": "Altitude",
  "Name": "Name"
};